@@ -1,9 +1,9 @@
  /******************************************************************
  *	              A.L.E.C's LMS Daemon
  *******************************************************************
- *  LMS version 1.1.5 Amaonet
+ *  LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- * $Id: almsd.c,v 1.12 2003/12/04 21:57:41 alec Exp $ 
+ * $Id: almsd.c,v 1.17 2004/02/18 12:49:22 lukasz Exp $ 
  */
 
 #include <unistd.h>
@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
     unsigned char *db, *user, *passwd, *host; //db connection params
     int port;				//
     dictionary *ini;			//config
-    int reload;    
+    int reload, reload_t = 0;    
     unsigned char *instance, *instances;
 
     	// read command line args
@@ -66,7 +66,7 @@ int main(int argc, char *argv[])
                 	break;
 		case 'h':
         	default:
-			printf("A.L.E.C's LMS Daemon v.1.0beta. Command line options:\n");
+			printf("A.L.E.C's LMS Daemon v.1.0. Command line options:\n");
 			printf(" -c \tpath to config file (default: /etc/lms/lms.ini)\n");
                 	printf(" -b \tfork in background\n");
                 	printf(" -s \tthe time the run sleeps for (seconds)\n");
@@ -147,6 +147,7 @@ int main(int argc, char *argv[])
 
     	// main loop ****************************************************
     	for (;;) {
+		int time;
 		reload = 0;
 	
 		// try to connect to database
@@ -160,9 +161,12 @@ int main(int argc, char *argv[])
         	if( quit )
    	    		reload = 1;
 		else {
-	    		if( (res =  db_query("SELECT COUNT(*) AS number FROM reload"))!=NULL ) {
-				if( atoi(db_get_data(res,0,"number"))>0 )
-	    	    		reload = 1;
+	    		if( (res =  db_query("SELECT time FROM timestamps WHERE tablename = '_force'"))!=NULL ) {
+				time = atoi(db_get_data(res,0,"time"));
+				if( time>0 && time!=reload_t ) {
+					reload = 1;
+					reload_t = time;
+				}
 				db_free(res);
 	    		}
 		}
@@ -237,11 +241,6 @@ int main(int argc, char *argv[])
 			free(instances);
 			iniparser_freedict(ini);
 
-	 		// empty reload table 
-			db_exec("DELETE FROM reload"); 
-#ifdef DEBUG1
-			syslog(LOG_INFO,"DEBUG: [lmsd] table reload flushed");
-#endif
 		} // end of reload *****************************************
 		db_disconnect();	  
 		if (quit) termination_handler(0);
