@@ -1,7 +1,7 @@
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: hostfile.c,v 1.9 2003/11/27 20:43:49 alec Exp $
+ *  $Id: hostfile.c,v 1.13 2004/03/02 13:13:20 alec Exp $
  */
 
 #include <stdio.h>
@@ -29,8 +29,8 @@
 #include "almsd.h"
 #include "hostfile.h"
 
+unsigned long htonl(unsigned long);
 unsigned long inet_addr(char *);
-char * inet_ntoa(unsigned long);
 
 void reload(GLOBAL *g, struct hostfile_module *hm)
 {
@@ -43,32 +43,42 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	{
 		fprintf(fh, "%s", hm->prefix);
 		
-		if( (res = g->db_query("SELECT name, mac, ipaddr, access FROM nodes ORDER BY ipaddr"))!=NULL) {
+		if( (res = g->db_pquery("SELECT name, mac, INET_NTOA(ipaddr) AS ip, access FROM nodes ? ORDER BY ipaddr",(hm->skip_dev_ips ? "WHERE ownerid<>0" : "")))!=NULL) {
 		
 			for(i=0; i<res->nrows; i++) {
-				unsigned char *literal_mac, *literal_ip, *literal_access, *name;
+				unsigned char *mac, *ip, *access, *name;
 			
-				literal_mac = g->db_get_data(res,i,"mac");
-				literal_ip  = inet_ntoa(inet_addr(g->db_get_data(res,i,"ipaddr")));
-				literal_access = g->db_get_data(res,i,"access");
-				name = (unsigned char *)g->str_lwc(g->db_get_data(res,i,"name"));
+				mac 	= g->db_get_data(res,i,"mac");
+				ip  	= g->db_get_data(res,i,"ip");
+				access 	= g->db_get_data(res,i,"access");
+				name 	= (unsigned char *) g->str_lwc(g->db_get_data(res,i,"name"));
 
-				if(literal_ip && literal_mac && literal_access) {
+				if(ip && mac && access) {
 					
-					unsigned char *pattern, *s;
+					unsigned long inet = inet_addr(ip);
+					int j;
+					
+					for(j=0; j<hm->netcount; j++)
+						if(hm->networks[j].network == (inet & hm->networks[j].netmask)) 
+							break;
+					
+					if( j != hm->netcount ) {
+
+						unsigned char *pattern, *s;
 				
-					if(*literal_access == '1')
-						pattern = hm->grant;
-					else
-						pattern = hm->deny;
+						if(*access == '1')
+							pattern = hm->grant;
+						else
+							pattern = hm->deny;
 				
-					s = strdup(pattern);
-					g->str_replace(&s, "%i", literal_ip);
-					g->str_replace(&s, "%m", literal_mac);
-					g->str_replace(&s, "%n", name);
+						s = strdup(pattern);
+						g->str_replace(&s, "%i", ip);
+						g->str_replace(&s, "%m", mac);
+						g->str_replace(&s, "%n", name);
 				
-					fprintf(fh, "%s", s);
-					free(s);
+						fprintf(fh, "%s", s);
+						free(s);
+					}
 				}
 			}
 		g->db_free(res);
@@ -89,13 +99,16 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	free(hm->deny);
 	free(hm->file);
 	free(hm->command);
+	free(hm->networks);
 }
 
 struct hostfile_module * init(GLOBAL *g, MODULE *m)
 {
 	struct hostfile_module *hm;
 	unsigned char *instance, *s;
+	unsigned char *networks, *net;
 	dictionary *ini;
+	int nc = 0;
 	
 	if(g->api_version != APIVERSION) 
 		return(NULL);
@@ -114,20 +127,75 @@ struct hostfile_module * init(GLOBAL *g, MODULE *m)
 	free(s); s = g->str_concat(instance,":end");
 	hm->append = strdup(g->iniparser_getstring(ini, s, "/usr/sbin/iptables -A FORWARD -j REJECT\n"));
 	free(s); s = g->str_concat(instance,":grantedhost");	
-	hm->grant = strdup(g->iniparser_getstring(ini, s, "/usr/sbin/iptables -A FORWARD -s %i -m mac --mac-source %m -j ACCEPT\n"));
+	hm->grant = strdup(g->iniparser_getstring(ini, s, "/usr/sbin/iptables -A FORWARD -s %i -m mac --mac-source %m -j ACCEPT\n/usr/sbin/iptables -A FORWARD -d %i -j ACCEPT\n"));
 	free(s); s = g->str_concat(instance,":deniedhost");
 	hm->deny = strdup(g->iniparser_getstring(ini, s, "/usr/sbin/iptables -A FORWARD -s %i -m mac --mac-source %m -j REJECT\n"));
+	free(s); s = g->str_concat(instance,":skip_dev_ips");
+	hm->skip_dev_ips = g->iniparser_getboolean(ini, s, 1);
 	free(s); s = g->str_concat(instance,":file");
 	hm->file = strdup(g->iniparser_getstring(ini, s, "/tmp/hostfile"));
 	free(s); s = g->str_concat(instance,":command");
 	hm->command = strdup(g->iniparser_getstring(ini, s, ""));
+	free(s); s = g->str_concat(instance, ":networks");
+	networks = strdup(g->iniparser_getstring(ini, s, "192.168.0.0/16 10.0.0.0/8"));
+	hm->networks = NULL;
 
 	g->iniparser_freedict(ini);
 	free(instance);
 	free(s);
+
+	for( net=strtok(networks," "); net!=NULL; net=strtok(NULL," ") ) { 
+		unsigned char *prefixlen;
+		unsigned long network;
+		unsigned long netmask;
+		unsigned char netmask_valid;
+		prefixlen = index(net, '/');
+
+		netmask_valid = 0;
+
+		if( prefixlen ) {
+			*prefixlen = 0;
+			prefixlen ++;
+			if(index(prefixlen, '.')) {
+				netmask = inet_addr(prefixlen);
+				netmask_valid = 1;
+			}
+			else {
+				int len = atoi(prefixlen);
+				if( len >= 0 && len <= 32 ) {
+					netmask = 0xffffffff;
+					len = 32 - len;
+					while( len ) {
+						netmask = netmask << 1;
+						len--;
+					}
+					netmask = htonl(netmask);
+					netmask_valid = 1;
+				}
+			}
+		}
+	
+		network = inet_addr(net);
+		if( !netmask_valid ) { // network mask autosense 
+		
+			if(! (network & 0x000000ff)) netmask = 0xffffff00;
+			if(! (network & 0x0000ffff)) netmask = 0xffff0000;
+			if(! (network & 0x00ffffff)) netmask = 0xff000000;
+		}
+		
+		hm->networks = realloc(hm->networks, (sizeof(struct hosts_net) * (nc+1)));
+		hm->networks[nc].network = network;
+		hm->networks[nc].netmask = netmask;
+		nc++;
+	}
+	free(networks);
+
+	if( !(hm->netcount = nc) ) {
+		syslog(LOG_ERR, "[%s/hostfile] No networks specified. Set 'networks' in lms.ini section [%s]", hm->base.instance, hm->base.instance);
+		return(NULL);
+	}
 #ifdef DEBUG1
 	syslog(LOG_INFO,"DEBUG: [%s/hostfile] initialized", hm->base.instance);
 #endif
 	return(hm);
 }
-
