@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Session.class.php,v 1.44 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: Session.class.php,v 1.45 2004/03/02 20:38:28 lexx Exp $
  */
 
 class Session {
@@ -35,8 +35,8 @@ class Session {
 	var $last;
 	var $lastip;
 	var $error;
-	var $_version = '1.3.0 Apophis';
-	var $_revision = '$Revision: 1.44 $';
+	var $_version = '1.3.1 Maybourne';
+	var $_revision = '$Revision: 1.45 $';
 
 	function Session(&$DB,$timeout = 600)
 	{
@@ -114,7 +114,7 @@ class Session {
 	{
 		if( (time()-$_SESSION[session_timestamp]) > $timeout )
 		{
-			$this->error="Przekroczye limit czasu bezczynnoci (".$timeout." sekund).";
+			$this->error=str_replace("%s",$timeout,gettext("Your login time was timetout. (%s sec)"));
 			return FALSE;
 		}
 		else
@@ -133,9 +133,9 @@ class Session {
 		else 
 		{
 			if(isset($this->login))
-				$this->error="Bdne haso lub nazwa uytkownika.";
+				$this->error=gettext("Wrong username or password");
 			else
-				$this->error="Prosz si zalogowa.";
+				$this->error=gettext("Please login yourself");
 			return FALSE;
 		}
 	}
