@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.54 2003/12/04 03:03:40 lukasz Exp $
+ *  $Id: common.php,v 1.59 2004/03/03 23:37:36 lukasz Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -900,48 +900,27 @@ function setunits($data)  // for traffic data
 	return array($number, $unit);
 }
 
-/*
- * $Log: common.php,v $
- * Revision 1.54  2003/12/04 03:03:40  lukasz
- * - cosmetics
- *
- * Revision 1.53  2003/10/08 00:05:51  lukasz
- * - lokalizowalna data
- *
- * Revision 1.52  2003/10/07 18:30:51  alec
- * nie potrzebujemy ju get_ip_range...(), teraz przeszukiwanie po adresie czciowym zostao przerzucone z sql'a na php w SearchNodeList()
- *
- * Revision 1.51  2003/10/06 22:21:33  alec
- * jeszcze jeden warunek w get_ip_range...()
- *
- * Revision 1.50  2003/10/06 22:19:16  alec
- * popraweczka - dodany komentarz
- *
- * Revision 1.49  2003/10/06 22:18:23  alec
- * nowa rozbudowana funkcja SearchNodeList() - na adresach IP dziaa prawie jak LIKE
- *
- * Revision 1.48  2003/10/02 03:25:55  lukasz
- * - some cosmetics
- *
- * Revision 1.47  2003/09/23 18:43:58  alec
- * added get_ip_range_from_ip_part() for nodesearch
- *
- * Revision 1.46  2003/09/15 20:53:23  alec
- * function setunits for Traffic() added
- *
- * Revision 1.45  2003/09/09 23:40:03  lukasz
- * - added to_words
- *
- * Revision 1.44  2003/09/05 02:02:50  lukasz
- * - format fix
- *
- * Revision 1.43  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *redhat's :>
- *
- * Revision 1.42  2003/08/18 16:57:00  lukasz
- * - more cvs tags :>
- *
- */
+function r_trim($array)
+{
+	foreach($array as $key => $value)
+		if(is_array($value))
+			$array[$key] = r_trim($value);
+		else
+			$array[$key] = trim($value);
+	
+	return $array;
+}
+
+function getdir($pwd = './', $pattern = '^.*$')
+{
+	if ($handle = @opendir($pwd))
+	{
+		while (($file = readdir($handle)) !== FALSE)
+			if(ereg($pattern,$file))
+				$files[] = $file;
+		closedir($handle);
+	}
+	return $files;
+}
 
 ?>
