@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: fortunes.php,v 1.2 2003/11/18 20:49:46 alec Exp $
+ *  $Id: fortunes.php,v 1.6 2004/02/22 14:15:36 hunter Exp $
  */
 
 $fortunes[] = "Moesz si pokaleczy wymachujc siekier?";
@@ -91,27 +91,19 @@ $fortunes[] = "19:16.31| <@Baseciq> SELECT users.id, lastname, SUM((type * -2 +
 $fortunes[] = "Lexx (0:16)
 GPL nie przewiduje zdaje sie braku odpowiedzialnosci za smierc przez kod ;]";
 
+$fortunes[] = "Subject: [lms] Re: Sieci
+
+Witam.
+[hunter napisa:]
+> e, to nie Ty miae z arpami co nie tak jako tak ze 3 krzynki i p
+> winiacza temu?
+
+Tak, ustawiaem arp 00:00:00:00:00:00 dla adresw broadcastowych i
+pada mi wins ;-)
+--
+ukasz Jarosaw Mozer ;]";
+
 mt_srand ((double) microtime()* 100000000);
 $layout[fortune] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];
 
-/*
- * $Log: fortunes.php,v $
- * Revision 1.2  2003/11/18 20:49:46  alec
- * literwka bts#00000079
- *
- * Revision 1.1  2003/09/24 22:31:43  lukasz
- * - changed 'TipOfTheDay' to 'fortunes'
- *
- * Revision 1.17  2003/09/11 17:18:17  lukasz
- * - Lexx zaczyna normalnie ;>
- *
- * Revision 1.16  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.15  2003/08/18 16:57:00  lukasz
- * - more cvs tags :>
- *
- */
-
 ?>
