@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,13 +21,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: language.php,v 1.3 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: language.php,v 1.5 2004/03/02 20:38:28 lexx Exp $
  */
 
-// Plik do ustawiania locales i do translacji...
-// Chwilowo tutaj nie ma nic, naprawd nic, poprostu potrzebne do eksperymentw paru.
+$language = 'en';
+$langs = explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE']);
+foreach ($langs as $val) {
+    switch (substr($val, 0, 2)) {
+	case 'pl':
+            $language = 'pl';
+	    setlocale(LC_ALL, 'pl_PL');
+            break 2;
+        case 'en':
+	    $language = 'en';
+	    setlocale(LC_ALL, 'en_US');
+	    break 2;
+    }
+}
 
-// ustawienie komunikatw syst. na polskie
-setlocale(LC_MESSAGES,'pl_PL');
-// ustawienie formatu czasu na polski
-setlocale(LC_TIME,'pl_PL');
+bindtextdomain("lms", "$_LIB_DIR/locale");
+textdomain("lms");
+
+?>
\ No newline at end of file
