@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,22 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminlist.php,v 1.13 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: adminlist.php,v 1.17 2004/02/21 19:38:16 lukasz Exp $
  */
 
-$layout[pagetitle] = "Administratorzy";
+$layout['pagetitle'] = "Administratorzy";
+
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('adminslist',$LMS->GetAdminList());
+$SMARTY->display('adminlist.html');
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("adminslist",$LMS->GetAdminList());
-$SMARTY->display("adminlist.html");
-/*
- * $Log: adminlist.php,v $
- * Revision 1.13  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.12  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
\ No newline at end of file
