@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancelist.php,v 1.28 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: balancelist.php,v 1.29 2004/02/21 19:38:16 lukasz Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
@@ -45,16 +45,16 @@ $page = (! $_GET['page'] ? ceil($listdata['totalpos']/$pagelimit) : $_GET['page'
 $start = ($page - 1) * $pagelimit;
 
 $layout['pagetitle'] = "Bilans finansowy";
-$SMARTY->assign("layout",$layout);
+$SMARTY->assign('layout',$layout);
 
-$SMARTY->assign("balancelist",$balancelist);
-$SMARTY->assign("listdata",$listdata);
-$SMARTY->assign("start",$start);
-$SMARTY->assign("prev",$prev);
-$SMARTY->assign("next",$next);
-$SMARTY->assign("page",$page);
-$SMARTY->assign("pagelimit",$pagelimit);
-$SMARTY->assign("start",$start);
-$SMARTY->display("balancelist.html");
+$SMARTY->assign('balancelist',$balancelist);
+$SMARTY->assign('listdata',$listdata);
+$SMARTY->assign('start',$start);
+$SMARTY->assign('prev',$prev);
+$SMARTY->assign('next',$next);
+$SMARTY->assign('page',$page);
+$SMARTY->assign('pagelimit',$pagelimit);
+$SMARTY->assign('start',$start);
+$SMARTY->display('balancelist.html');
 
 ?>
