@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,24 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.12 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: balancenew.php,v 1.17 2004/02/21 19:38:16 lukasz Exp $
  */
 
-$_SESSION[backto] = $_SERVER[QUERY_STRING];
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+
+$layout['pagetitle'] = "Nowa operacja finansowa";
+$SMARTY->assign('comment',$_SESSION['addbc']);
+$SMARTY->assign('time', $_SESSION['addbt']);
+$SMARTY->assign('value', $_SESSION['addbv']);
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('users',$LMS->GetUserNames());
+$SMARTY->display('balancenew.html');
 
-$layout[pagetitle]="Nowa operacja finansowa";
-$SMARTY->assign("comment",$_SESSION[addbc]);
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("users",$LMS->GetUserNames());
-$SMARTY->display("balancenew.html");
-/*
- * $Log: balancenew.php,v $
- * Revision 1.12  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.11  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
\ No newline at end of file
