@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chpasswd.php,v 1.13 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: chpasswd.php,v 1.14 2004/02/21 19:38:16 lukasz Exp $
  */
 
-$passwd = $_POST[passwd];
+$passwd = $_POST['passwd'];
 
 $id = $SESSION->id;
 
@@ -32,32 +32,32 @@ if($LMS->AdminExists($id))
 {
 	if(isset($passwd))
 	{
-		if($passwd[passwd] == "" || $passwd[confirm] == "")
-			$error[password] .= "Haso nie moe by puste!<BR>";
+		if($passwd['passwd'] == "" || $passwd['confirm'] == "")
+			$error['password'] .= "Haso nie moe by puste!<BR>";
 		
-		if($passwd[passwd] != $passwd[confirm])
-			$error[password] .= "Podane hasa si rni!";
+		if($passwd['passwd'] != $passwd['confirm'])
+			$error['password'] .= "Podane hasa si rni!";
 		
 		if(!$error)
 		{
-			$LMS->SetAdminPassword($id,$passwd[passwd]);
+			$LMS->SetAdminPassword($id,$passwd['passwd']);
 			header("Location: ?m=welcome");
 		}
 	}
 
-	$passwd[realname] = $LMS->GetAdminName($id);
-	$passwd[id] = $id;
-	$layout[pagetitle]="Zmiana hasa";
-	$SMARTY->assign("layout",$layout);
-	$SMARTY->assign("error",$error);
-	$SMARTY->assign("passwd",$passwd);
-	$SMARTY->assign("target","?m=chpasswd");
-	$SMARTY->display("adminpasswd.html");
+	$passwd['realname'] = $LMS->GetAdminName($id);
+	$passwd['id'] = $id;
+	$layout['pagetitle'] = "Zmiana hasa";
+	$SMARTY->assign('layout',$layout);
+	$SMARTY->assign('error',$error);
+	$SMARTY->assign('passwd',$passwd);
+	$SMARTY->assign('target',"?m=chpasswd");
+	$SMARTY->display('adminpasswd.html');
 
 }
 else
 {
-	header("Location: ?m=".$_SESSION[lastmodule]);
+	header("Location: ?m=".$_SESSION['lastmodule']);
 	die;
 }
 
