@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,23 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbdel.php,v 1.18 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: dbdel.php,v 1.19 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if($_GET[is_sure])
+if($_GET['is_sure'])
 {
-	$LMS->DatabaseDelete($_GET[db]);
-	header("Location: ?m=".$_SESSION[lastmodule]);
+	$LMS->DatabaseDelete($_GET['db']);
+	header("Location: ?m=".$_SESSION['lastmodule']);
 	die;
 } else
 {
-	$layout[pagetitle]="Usunicie bazy danych";
-	$SMARTY->assign("layout",$layout);
-	$SMARTY->display("header.html");
+	$layout['pagetitle'] = "Usunicie bazy danych";
+	$SMARTY->assign('layout',$layout);
+	$SMARTY->display('header.html');
 	echo "<H1>Usunicie bazy danych</H1>";
-	echo "<p>Czy jeste pewien e chcesz usun baz danych utworzon ".date("Y/m/d H:i.s",$_GET[db])."?</p>";
-	echo "<a href=\"?m=dbdel&db=".$_GET[db]."&is_sure=1\">Tak, jestem pewien</A>";
-	$SMARTY->display("footer.html");
+	echo "<p>Czy jeste pewien e chcesz usun baz danych utworzon ".date("Y/m/d H:i.s",$_GET['db'])."?</p>";
+	echo "<a href=\"?m=dbdel&db=".$_GET['db']."&is_sure=1\">Tak, jestem pewien</A>";
+	$SMARTY->display('footer.html');
 }
 
 ?>
\ No newline at end of file
