@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,11 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbnew.php,v 1.15 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: dbnew.php,v 1.16 2004/02/21 19:38:17 lukasz Exp $
  */
 
 $LMS->DatabaseCreate();
 
-header("Location: ?m=".$_SESSION[lastmodule]);
+header("Location: ?m=".$_SESSION['lastmodule']);
 
 ?>
\ No newline at end of file
