@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,23 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbrecover.php,v 1.20 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: dbrecover.php,v 1.21 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if($_GET[is_sure])
+if($_GET['is_sure'])
 {
 	$LMS->DatabaseCreate();
-	$LMS->DatabaseRecover($_GET[db]);
-	header("Location: ?m=".$_SESSION[lastmodule]);
+	$LMS->DatabaseRecover($_GET['db']);
+	header("Location: ?m=".$_SESSION['lastmodule']);
 	die;
 }else{
-	$layout[pagetitle]="Odtworzenie bazy danych danych";
-	$SMARTY->assign("layout",$layout);
-	$SMARTY->display("header.html");
+	$layout['pagetitle'] = "Odtworzenie bazy danych danych";
+	$SMARTY->assign('layout',$layout);
+	$SMARTY->display('header.html');
 	echo "<H1>Odtworzenie bazy danych danych</H1>";
-	echo "<p>Czy jeste pewien e chcesz odtworzy baz danych utworzon dnia ".date("Y/m/d H:i.s",$_GET[db])."?</p>";
-	echo "<a href=\"?m=dbrecover&db=".$_GET[db]."&is_sure=1\">Tak, jestem pewien</A>";
-	$SMARTY->display("footer.html");
+	echo "<p>Czy jeste pewien e chcesz odtworzy baz danych utworzon dnia ".date("Y/m/d H:i.s",$_GET['db'])."?</p>";
+	echo "<a href=\"?m=dbrecover&db=".$_GET['db']."&is_sure=1\">Tak, jestem pewien</A>";
+	$SMARTY->display('footer.html');
 }
 
 ?>
\ No newline at end of file
