@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,37 +21,30 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbview.php,v 1.14 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: dbview.php,v 1.18 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$layout[pagetitle]="Podgld bazy danych";
-$database = $LMS->DatabaseFetchContent($_GET[db]);
-if($_GET[rawmode]=="true")
+$layout['pagetitle'] = "Podgld bazy danych";
+
+$database = $LMS->DatabaseFetchContent($_GET['db']);
+
+if($_GET['rawmode']=="true")
 {
-	$database[rawmode] = TRUE;
-	if($_GET[save]=="true")
+	$database['rawmode'] = TRUE;
+	if($_GET['save']=="true")
 	{
 		header("Content-Type: application/octetstream");
-		header("Content-Disposition: attachment; filename=lms-backup-".date("Ymd-His",$_GET[db]).".sql");
+		header("Content-Disposition: attachment; filename=lms-backup-".date("Ymd-His",$_GET['db']).".sql");
 	}
 	else
 		header("Content-Type: text/plain; charset=ISO-8859-2");
 }
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("database",$database);
-if(!$database[rawmode])
-	$SMARTY->display("header.html");
-$SMARTY->display("dbview.html");
-if(!$database[rawmode])
-	$SMARTY->display("footer.html");
-/*
- * $Log: dbview.php,v $
- * Revision 1.14  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.13  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('database',$database);
+if(!$database['rawmode'])
+	$SMARTY->display('header.html');
+$SMARTY->display('dbview.html');
+if(!$database['rawmode'])
+	$SMARTY->display('footer.html');
 ?>
\ No newline at end of file
