@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: invoice.php,v 1.22 2004/02/21 19:38:17 lukasz Exp $
  */
 header('Content-Type: '.$LMS->CONFIG['invoices']['content_type']);
 if($LMS->CONFIG['invoices']['attachment_name'] != '')
@@ -36,7 +36,7 @@ if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
 		if($junk)
 			$ids[] = $markid;
 	sort($ids);
-	$which = ($_GET[which] != '' ? $_GET[which] : 'ORYGINA+KOPIA');
+	$which = ($_GET['which'] != '' ? $_GET['which'] : 'ORYGINA+KOPIA');
 	foreach($ids as $idx => $invoiceid)
 	{
 		echo '<PRE>';
