@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,39 +21,30 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netcmp.php,v 1.16 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: netcmp.php,v 1.20 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if(!$LMS->NetworkExists($_GET[id]))
+if(!$LMS->NetworkExists($_GET['id']))
 {
 	header("Location: ?m=netlist");
 	die;
 }
 
-$network[name] = $LMS->GetNetworkName($_GET[id]);
+$network['name'] = $LMS->GetNetworkName($_GET['id']);
 
-if($_GET[is_sure])
+if($_GET['is_sure'])
 {
-	$LMS->NetworkCompress($_GET[id]);
-	header("Location: ?m=".$_SESSION[lastmodule]."&id=".$_GET[id]);
+	$LMS->NetworkCompress($_GET['id']);
+	header("Location: ?m=".$_SESSION['lastmodule']."&id=".$_GET['id']);
 	die;
 }else{
-	$layout[pagetitle]="Porzdkowanie sieci ".strtoupper($network[name]);
-	$SMARTY->assign("layout",$layout);
-	$SMARTY->display("header.html");
-	echo "<H1>Porzdkowanie sieci ".strtoupper($network[name])."</H1>";
+	$layout['pagetitle'] = "Porzdkowanie sieci ".strtoupper($network['name']);
+	$SMARTY->assign('layout',$layout);
+	$SMARTY->display('header.html');
+	echo "<H1>Porzdkowanie sieci ".strtoupper($network['name'])."</H1>";
 	echo "<p>Czy jeste pewien e chcesz uporzdkowa t sie?</p>";
-	echo "<a href=\"?m=netcmp&id=".$_GET[id]."&is_sure=1\">Tak, jestem pewien</A>";
-	$SMARTY->display("footer.html");
+	echo "<a href=\"?m=netcmp&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien</A>";
+	$SMARTY->display('footer.html');
 }
-/*
- * $Log: netcmp.php,v $
- * Revision 1.16  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.15  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+
 ?>
\ No newline at end of file
