@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,17 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevadd.php,v 1.2 2003/10/05 21:18:49 alec Exp $
+ *  $Id: netdevadd.php,v 1.6 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$netdevdata = $_POST[netdev];
+$netdevdata = $_POST['netdev'];
 
 if(isset($netdevdata)) {
 	// Jakby to dziaao to by byo mio... :P
-	//if($netdevdata[ports] !="" && !eregi("^[0-9]{,4}$",$netdevdata[ports]))
-        //        $error[ports] = "Podana ilo portw jest bdna!";
-	if($netdevdata[name] == "")
-		$error[name] = "Pole nazwa nie moe by puste!";
+	//if($netdevdata['ports'] !="" && !eregi("^[0-9]{,4}$",$netdevdata['ports']))
+        //        $error['ports'] = "Podana ilo portw jest bdna!";
+	if($netdevdata['name'] == "")
+		$error['name'] = "Pole nazwa nie moe by puste!";
 
         if(!$error)
         {
@@ -42,20 +42,11 @@ if(isset($netdevdata)) {
 }
 		
 
-$layout[pagetitle]="Nowe urzdzenie";
+$layout['pagetitle'] = "Nowe urzdzenie";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("error",$error);
-$SMARTY->assign("netdev",$netdevdata);
-$SMARTY->display("netdevadd.html");
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('error',$error);
+$SMARTY->assign('netdev',$netdevdata);
+$SMARTY->display('netdevadd.html');
 
-/*
- * $Log: netdevadd.php,v $
- * Revision 1.2  2003/10/05 21:18:49  alec
- * ujenolicenie naglowkow
- *
- * Revision 1.1  2003/09/12 20:57:05  lexx
- * - netdev
- *
- */
 ?>
