@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,53 +21,41 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevdel.php,v 1.3 2003/10/08 04:39:38 lukasz Exp $
+ *  $Id: netdevdel.php,v 1.7 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if(! $LMS->NetDevExists($_GET[id]))
+if(! $LMS->NetDevExists($_GET['id']))
 {
 	header('Location: ?m=netdevlist');
 	die;
 }		
 
-$layout[pagetitle]="Usunicie urzdzenia ID: ".sprintf("%04d",$_GET[id]);
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("netdevid",$_GET[id]);
+$layout['pagetitle'] = "Usunicie urzdzenia ID: ".sprintf("%04d",$_GET['id']);
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('netdevid',$_GET['id']);
 
-if($LMS->CountNetDevLinks($_GET[id])>0)
+if($LMS->CountNetDevLinks($_GET['id'])>0)
 {
-	$body = "<H1>".$layout[pagetitle]."</H1>";
+	$body = "<H1>".$layout['pagetitle']."</H1>";
 	$body .= "<P>Nie mona usun urzdzenia ktre jest podczone do innych urzdze.</P>";
 }else{
-    if($_GET[is_sure]!=1)
+    if($_GET['is_sure']!=1)
     {
-	    $body = "<H1>".$layout[pagetitle]."</H1>";
+	    $body = "<H1>".$layout['pagetitle']."</H1>";
 	    $body .= "<P>Czy jeste pewien e chcesz usun urzdzenie?</P>"; 
-	    $body .= "<P><A HREF=\"?m=userdel&id=".$_GET[id]."&is_sure=1\">Tak, jestem pewien.</A></P>";
+	    $body .= "<P><A HREF=\"?m=userdel&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien.</A></P>";
     }else{
 	    header("Location: ?m=netdevlist");
-	    $body = "<H1>".$layout[pagetitle]."</H1>";
+	    $body = "<H1>".$layout['pagetitle']."</H1>";
 	    $body .= "<P>Urzdzenie zostao usunite.</P>";
-	    $LMS->DeleteNetDev($_GET[id]);
+	    $LMS->DeleteNetDev($_GET['id']);
     }
 }
 	
 
-$SMARTY->display("header.html");
-$SMARTY->assign("body",$body);
-$SMARTY->display("dialog.html");
-$SMARTY->display("footer.html");
+$SMARTY->display('header.html');
+$SMARTY->assign('body',$body);
+$SMARTY->display('dialog.html');
+$SMARTY->display('footer.html');
 
-/*
- * $Log: netdevdel.php,v $
- * Revision 1.3  2003/10/08 04:39:38  lukasz
- * - temporary save
- *
- * Revision 1.2  2003/09/21 18:07:47  lexx
- * - netdev
- *
- * Revision 1.1  2003/09/12 20:57:05  lexx
- * - netdev
- *
- */
 ?>
