@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,11 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: print.php,v 1.20 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: print.php,v 1.21 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$layout[pagetitle]="Wydruki";
-$SMARTY->assign("layout",$layout);
+$layout['pagetitle'] = "Wydruki";
+$SMARTY->assign('layout',$layout);
 
 $su = $DB->GetOne("SELECT min(time) FROM cash");
 $eu = $DB->GetOne("SELECT max(time) FROM cash");
@@ -50,27 +50,27 @@ for($d=$sy;$d<$ey+1;$d++)
 		$monthlist[] = "$d/$m";
 }
 
-$SMARTY->assign("monthlist",$monthlist);
+$SMARTY->assign('monthlist',$monthlist);
 
-switch($_GET[type])
+switch($_GET['type'])
 {
 	case "userlist":
-		$SMARTY->assign("userlist",$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
-		$SMARTY->display("printuserlist.html");
+		$SMARTY->assign('userlist',$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
+		$SMARTY->display('printuserlist.html');
 	break;
 
 	case "nodelist":
-		$SMARTY->assign("nodelist",$LMS->GetNodeList($_SESSION['nlo']));
-		$SMARTY->display("printnodelist.html");
+		$SMARTY->assign('nodelist',$LMS->GetNodeList($_SESSION['nlo']));
+		$SMARTY->display('printnodelist.html');
 	break;
 	
 	case "userlistminus":
-		$SMARTY->assign("userlist",$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
-		$SMARTY->display("printuserlistminus.html");
+		$SMARTY->assign('userlist',$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
+		$SMARTY->display('printuserlistminus.html');
 	break;
 
 	default:
-		$SMARTY->display("printindex.html");
+		$SMARTY->display('printindex.html');
 	break;
 }
 
