@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.1 Maybourne
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffadd.php,v 1.28 2003/12/01 02:12:48 lukasz Exp $
+ *  $Id: tariffadd.php,v 1.33 2004/02/21 19:38:17 lukasz Exp $
  */
 
 $tariffadd = $_POST['tariffadd'];
@@ -42,7 +42,7 @@ if(isset($tariffadd))
 	if(!(ereg("^[-]?[0-9.,]+$",$tariffadd['value'])))
 		$error['value'] = "Podana warto taryfy jest niepoprawna!";
 
-	if(!(ereg("^[-]?[0-9.,]+$",$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
+	if(!(ereg("^[0-9.,]+$",$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
 		$error['taxvalue'] = "Podana stawka podatku jest niepoprawna!";
 
 	if(!(ereg("^[0-9]+$", $tariffadd['uprate'])) && $tariffadd['uprate'] != "")
@@ -72,42 +72,11 @@ if(isset($tariffadd))
 	
 }
 
-$layout['pagetitle']="Nowa taryfa";
+$layout['pagetitle'] = "Nowa taryfa";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("error",$error);
-$SMARTY->assign("tariffadd",$tariffadd);
-$SMARTY->display("tariffadd.html");
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('error',$error);
+$SMARTY->assign('tariffadd',$tariffadd);
+$SMARTY->display('tariffadd.html');
 
-/*
- * $Log: tariffadd.php,v $
- * Revision 1.28  2003/12/01 02:12:48  lukasz
- * - tsave - do nowych faktur... jak si wypi to dokocz
- *
- * Revision 1.27  2003/10/05 20:47:02  alec
- * stream -> rate in errors
- *
- * Revision 1.26  2003/10/05 20:37:15  alec
- * ujednolicenie interfejsu
- *
- * Revision 1.25  2003/09/09 01:22:28  lukasz
- * - nowe finanse
- * - kosmetyka
- * - bugfixy
- * - i inne rzeczy o ktrych aktualnie nie pamitam
- *
- * Revision 1.24  2003/09/06 07:41:17  alec
- * dodana moliwo tworzenia taryfy bez uprate i downrate, kosmetyka
- *
- * Revision 1.23  2003/09/05 13:11:24  lukasz
- * - nowy sposb wywietlania informacji o bdach
- *
- * Revision 1.22  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.21  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
