@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,16 +21,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffmove.php,v 1.15 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: tariffmove.php,v 1.16 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if($LMS->TariffExists($_GET[from]) && $LMS->TariffExists($_GET[to]) && $_GET[is_sure] = 1)
+if($LMS->TariffExists($_GET['from']) && $LMS->TariffExists($_GET['to']) && $_GET['is_sure'] = 1)
 {
-	$LMS->TariffMove($_GET[from],$_GET[to]);
-	header("Location: ?m=tariffinfo&id=".$_GET[to]);
+	$LMS->TariffMove($_GET['from'],$_GET['to']);
+	header("Location: ?m=tariffinfo&id=".$_GET['to']);
 	die;
 }
 else
-	header("Location: ?".$_SESSION[backto]);
+	header("Location: ?".$_SESSION['backto']);
 
 ?>
\ No newline at end of file
