@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,21 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userbalance.php,v 1.23 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: userbalance.php,v 1.24 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if(!$LMS->UserExists($_GET[id]))
+if(!$LMS->UserExists($_GET['id']))
 	header("Location: ?m=userlist");
 
-$username=$LMS->GetUserName($_GET[id]);
-$id = $_GET[id];
+$username=$LMS->GetUserName($_GET['id']);
+$id = $_GET['id'];
 
-$layout[pagetitle]='Rachunek uytkownika: <A HREF="?m=userinfo&id='.$_GET[id].'">'.$username.'</A>';
+$layout['pagetitle'] = 'Rachunek uytkownika: <A HREF="?m=userinfo&id='.$_GET['id'].'">'.$username.'</A>';
 
-$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($_GET[id]));
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("username",$username);
-$SMARTY->assign("id",$id);
-$SMARTY->display("userbalance.html");
+$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($_GET['id']));
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('username',$username);
+$SMARTY->assign('id',$id);
+$SMARTY->display('userbalance.html');
 
 ?>
