@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,48 +21,48 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usersearch.php,v 1.21 2004/02/18 12:49:24 lukasz Exp $
+ *  $Id: usersearch.php,v 1.22 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$search = $_POST[search];
+$search = $_POST['search'];
 
-if(isset($search[s]))
-	$_GET[s] = $search[s];
+if(isset($search['s']))
+	$_GET['s'] = $search['s'];
 
-$layout[pagetitle]="Wyszukiwanie uytkownikw";
+$layout['pagetitle'] = 'Wyszukiwanie uytkownikw';
 if(!isset($search))
-	$search = $_SESSION[usersearch];
+	$search = $_SESSION['usersearch'];
 else
-	$_SESSION[usersearch] = $search;
+	$_SESSION['usersearch'] = $search;
 
-if(!isset($_GET[o]))
-	$o = $_SESSION[uslo];
+if(!isset($_GET['o']))
+	$o = $_SESSION['uslo'];
 else
-	$o = $_GET[o];
+	$o = $_GET['o'];
 
-$_SESSION[uslo] = $o;
+$_SESSION['uslo'] = $o;
 
-if(!isset($_GET[s]))
-	$s = $_SESSION[usls];	
+if(!isset($_GET['s']))
+	$s = $_SESSION['usls'];	
 else
-	$s = $_GET[s];
+	$s = $_GET['s'];
 	
-$_SESSION[usls] = $s;
+$_SESSION['usls'] = $s;
 				
-$layout[pagetitle]="Wyszukiwanie uytkownika";
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("header.html");
-$SMARTY->display("userheader.html");
+$layout['pagetitle'] = "Wyszukiwanie uytkownika";
+$SMARTY->assign('layout',$layout);
+$SMARTY->display('header.html');
+$SMARTY->display('userheader.html');
 
-if($_GET[search]==1 || isset($_GET[search]))
+if($_GET['search']==1 || isset($_GET['search']))
 {
 	$userlist = $LMS->SearchUserList($o,$s,$search);
-	$SMARTY->assign("userlist",$userlist);
-	$SMARTY->display("usersearchresults.html");
+	$SMARTY->assign('userlist',$userlist);
+	$SMARTY->display('usersearchresults.html');
 }
 else
-	$SMARTY->display("usersearch.html");
+	$SMARTY->display('usersearch.html');
 
-$SMARTY->display("footer.html");
+$SMARTY->display('footer.html');
 
-?>
\ No newline at end of file
+?>
